
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef CALIBRATE_H
#define CALIBRATE_H

/**
 * Nullpunkt der EKG-Verstrker. (idealerweise 127 oder 128)
 * Mevorschrift: alle Eingnge auf Masse, Wert aus Rohdaten ablesen.
 */
const int EKG_zero[3] = { 130, 128, 130 };

/**
 * Verstrkungsfaktor der EKG-Verstrker.
 * Mevorschrift: Eingangsspannung mit 1 Hz und etwa 1 mV anlegen und
 * Spitze-Sptize-Amplitude aus Rohdaten ablesen.<br>
 * Verstrkungsfaktor = Spannung_pp [mV] / ( Maximalwert - Minimalwert )
 */
const float EKG_amp[3] = { 0.9/151, 0.9/165, 0.9/153 };

/**
 * Samplingrate bzw Zeitschrittweite fr die Signalverarbeitung.
 * <p>
 * <strong>Abschtzung:</strong> 9600 baud ~= 800 cps = 
 * 200 Wertquartette / Sekunde, also
 * <tt>dt</tt> = 5 ms = 0.005 s.
 * <p>
 * <strong>Erfahrungswert:</strong> Die bertragung ist etwas langsamer. 
 * <tt>dt</tt> = 0.006 s.
 * <p>
 * Die Definition als Makro erlaubt eine Verwendung auch in Strings.
 */
#define EKG_TimeStep 0.006

#endif
